jQuery plugin: Tablesorter 2.0 - Writing custom parsers

# tablesorter

## Writing custom parsers

### Flexible client-side table sorting

Back to documentation

# Demo

Name | Major | Gender | English | Japanese | Calculus | Overall grades
--- | --- | --- | --- | --- | --- | ---
Student01 | Languages | male | 80 | 70 | 75 | bad
Student02 | Mathematics | male | 90 | 88 | 100 | good
Student03 | Languages | female | 85 | 95 | 80 | medium

# Javascript

# HTML